import * as DynamoDB from 'aws-sdk/clients/dynamodb';
import { Observable } from 'rxjs/Observable';
import { ModelConstructor } from '../model/model-constructor';
import { DynamoApiOperations } from './dynamo-api-operations.type';
import { DeleteRequest } from './request/delete/delete.request';
import { GetRequest } from './request/get/get.request';
import { PutRequest } from './request/put/put.request';
import { QueryRequest } from './request/query/query.request';
import { ScanRequest } from './request/scan/scan.request';
import { UpdateRequest } from './request/update/update.request';
import { SessionValidityEnsurer } from './session-validity-ensurer.type';
import { TableNameResolver } from './table-name-resolver.type';
export declare class DynamoStore<T> {
    private modelClazz;
    private static REGEX_TABLE_NAME;
    private readonly dynamoRx;
    private readonly mapper;
    readonly tableName: string;
    constructor(modelClazz: ModelConstructor<T>, tableNameResolver?: TableNameResolver, sessionValidityEnsurer?: SessionValidityEnsurer);
    readonly dynamoDb: DynamoDB;
    put(item: T): PutRequest<T>;
    get(partitionKey: any, sortKey?: any): GetRequest<T>;
    update(partitionKey: any, sortKey?: any): UpdateRequest<T>;
    delete(partitionKey: any, sortKey?: any): DeleteRequest<T>;
    scan(): ScanRequest<T>;
    query(): QueryRequest<T>;
    makeRequest<Z>(operation: DynamoApiOperations, params?: {
        [key: string]: any;
    }): Observable<Z>;
    private createBaseParams();
}
